==> sife-0.0.37.tgz: package/srcs/App.js <==
/*global window,$*/

(function SifeApp(AppNameSpace){
	// start by defining a global namespace
	var App = window[AppNameSpace] = {
		breakpoints: null,// hash of breakpoints {sm:10, lg:20}
		'@media': function mq(i){
			var q = i.replace('--','');
			if('matchMedia'in window){
				return window.matchMedia('(min-width: '+App.breakpoints[q]+'em)').matches;
			}
			return false;
		},
		components: {} ///@TODO use get/set API instead of public object
	};
	/* __INSERT_BREAKPOINTS__ */

	var jsComponents = {};
	/* __INSERT_JS_COMPONENTS__ */


	var loadedSources = {};

	function loadComponent(componentId, $el){
		var component = jsComponents[componentId];
		if(component){
			// load external sources
			var externalSources = normalizeExternalSources(component.externalSources);

			$.when(
				loadSourcesParallel(externalSources.parallel),
				loadSourcesSeries(externalSources.series)
			).then(function(){
				component($el);
			});

		}
	}

	function normalizeExternalSources(toNormalize){
		var externalSources = {
			parallel: [],
			series: []
		};

		if(toNormalize){
			if(toNormalize instanceof Array){
				externalSources.parallel = toNormalize;
			}else if(toNormalize.parallel || toNormalize.series){
				externalSources.parallel = toNormalize.parallel;
				externalSources.series = toNormalize.series;
			}
		}

		return externalSources;
	}

	function loadSourcesParallel(urls){
		var promises = [];
		for (var i = 0; i < urls.length; i++) {
			promises.push(loadSource(urls[i]));
		}
		return $.when.apply($, promises);
	}

	function loadSourcesSeries(urls){
		var promise = $.Deferred();

		function loadOne(index){
			if(!urls[index]){
				promise.resolve();
			}else{
				loadSource(urls[index]).then(function(){
					loadOne(index+1);
				});
			}

		}
		loadOne(0);
		return promise;
	}

	function loadSource(url){
		if(typeof loadedSources[url] !== 'undefined'){
			return loadedSources[url];
		}

		var promise;

		if(url.indexOf('.css') > -1){
			// CSS
			promise = $.Deferred();
			loadCSS(url, null, function(){
				promise.resolve();
			});

		}else{
			// JS
			promise = $.getScript(url);
		}
		loadedSources[url] = promise;
		return promise;
	}

	(function init(){

		// load all components on page
		$('[data-sife-js]').each(function(){
			var componentId = $(this).data('sife-js');
			loadComponent(componentId, $(this));
		});

		// load main script
		if(jsComponents.main){
			loadComponent('main');
		}

		// de-activate init function
		init = function(){};
	}());


}('App'));


/*!
loadCSS: load a CSS file asynchronously.
[c]2014 @scottjehl, Filament Group, Inc.
Modified by Easyfairs
Licensed MIT
*/

/* exported loadCSS */
function loadCSS( href, before, callback ){
	"use strict";
	// Arguments explained:
	// `href` is the URL for your CSS file.
	// `before` optionally defines the element we'll use as a reference for injecting our <link>
	// By default, `before` uses the first <script> element in the page.
	// However, since the order in which stylesheets are referenced matters, you might need a more specific location in your document.
	// If so, pass a different reference element to the `before` argument and it'll insert before that instead
	// note: `insertBefore` is used instead of `appendChild`, for safety re: http://www.paulirish.com/2011/surefire-dom-element-insertion/
	var ss = window.document.createElement( "link" );
	var ref = before || window.document.getElementsByTagName( "script" )[ 0 ];
	var sheets = window.document.styleSheets;
	ss.rel = "stylesheet";
	ss.href = href;
	// temporarily, set media to something non-matching to ensure it'll fetch without blocking render
	ss.media = "only x";

	// inject link
	ref.parentNode.insertBefore( ss, ref );
	// This function sets the link's media back to `all` so that the stylesheet applies once it loads
	// It is designed to poll until document.styleSheets includes the new sheet.
	ss.onloadcssdefined = function( cb ){
		var defined;
		for( var i = 0; i < sheets.length; i++ ){
			if( sheets[ i ].href && sheets[ i ].href === ss.href ){
				defined = true;
			}
		}
		if( defined ){
			cb();
		} else {
			setTimeout(function() {
				ss.onloadcssdefined( cb );
			});
		}
	};
	ss.onloadcssdefined(function() {
		ss.media = "all";
		if(callback){
			callback();
		}
	});
	return ss;
}

==> sife-0.0.41.tgz: package/srcs/App.js <==
/*global window,$,document*/

(function SifeApp(AppNameSpace){
	// start by defining a global namespace
	var App = window[AppNameSpace] = {
		breakpoints: null,// hash of breakpoints {sm:10, lg:20}
		'@media': function mq(i){
			var q = i.replace('--','');
			if('matchMedia'in window){
				return window.matchMedia('(min-width: '+App.breakpoints[q]+'em)').matches;
			}
			return false;
		},
		components: {}, ///@TODO use get/set API instead of public object
		loadComponents: loadComponents
	};
	/* __INSERT_BREAKPOINTS__ */

	var jsComponents = {};
	/* __INSERT_JS_COMPONENTS__ */


	var loadedSources = {};

	function loadComponent(componentId, $el){
		var component = jsComponents[componentId];
		if(component){
			// load external sources
			var externalSources = normalizeExternalSources(component.externalSources);

			$.when(
				loadSourcesParallel(externalSources.parallel),
				loadSourcesSeries(externalSources.series)
			).then(function(){
				component($el);
			});

		}
	}

	function loadComponents($el){
		$el = $el || $(document.body);
		$el.find('[data-sife-js]').each(function(){
			var $this = $(this);
			if(!$this.attr('data-sife-js-initialized')){
				$this.attr('data-sife-js-initialized', '1');
				var componentId = $this.data('sife-js');
				loadComponent(componentId, $this);
			}

		});
	}

	function normalizeExternalSources(toNormalize){
		var externalSources = {
			parallel: [],
			series: []
		};

		if(toNormalize){
			if(toNormalize instanceof Array){
				externalSources.parallel = toNormalize;
			}else if(toNormalize.parallel || toNormalize.series){
				externalSources.parallel = toNormalize.parallel;
				externalSources.series = toNormalize.series;
			}
		}

		return externalSources;
	}

	function loadSourcesParallel(urls){
		var promises = [];
		for (var i = 0; i < urls.length; i++) {
			promises.push(loadSource(urls[i]));
		}
		return $.when.apply($, promises);
	}

	function loadSourcesSeries(urls){
		var promise = $.Deferred();

		function loadOne(index){
			if(!urls[index]){
				promise.resolve();
			}else{
				loadSource(urls[index]).then(function(){
					loadOne(index+1);
				});
			}

		}
		loadOne(0);
		return promise;
	}

	function loadSource(url){
		if(typeof loadedSources[url] !== 'undefined'){
			return loadedSources[url];
		}

		var promise;

		if(url.indexOf('.css') > -1){
			// CSS
			promise = $.Deferred();
			loadCSS(url, null, function(){
				promise.resolve();
			});

		}else{
			// JS
			promise = $.getScript(url);
		}
		loadedSources[url] = promise;
		return promise;
	}

	(function init(){

		// load all components on page
		App.loadComponents();

		// load main script
		if(jsComponents.main){
			loadComponent('main');
		}

		// de-activate init function
		init = function(){};
	}());


}('App'));


/*!
loadCSS: load a CSS file asynchronously.
[c]2014 @scottjehl, Filament Group, Inc.
Modified by Easyfairs
Licensed MIT
*/

/* exported loadCSS */
function loadCSS( href, before, callback ){
	"use strict";
	// Arguments explained:
	// `href` is the URL for your CSS file.
	// `before` optionally defines the element we'll use as a reference for injecting our <link>
	// By default, `before` uses the first <script> element in the page.
	// However, since the order in which stylesheets are referenced matters, you might need a more specific location in your document.
	// If so, pass a different reference element to the `before` argument and it'll insert before that instead
	// note: `insertBefore` is used instead of `appendChild`, for safety re: http://www.paulirish.com/2011/surefire-dom-element-insertion/
	var ss = window.document.createElement( "link" );
	var ref = before || window.document.getElementsByTagName( "script" )[ 0 ];
	var sheets = window.document.styleSheets;
	ss.rel = "stylesheet";
	ss.href = href;
	// temporarily, set media to something non-matching to ensure it'll fetch without blocking render
	ss.media = "only x";

	// inject link
	ref.parentNode.insertBefore( ss, ref );
	// This function sets the link's media back to `all` so that the stylesheet applies once it loads
	// It is designed to poll until document.styleSheets includes the new sheet.
	ss.onloadcssdefined = function( cb ){
		var defined;
		for( var i = 0; i < sheets.length; i++ ){
			if( sheets[ i ].href && sheets[ i ].href === ss.href ){
				defined = true;
			}
		}
		if( defined ){
			cb();
		} else {
			setTimeout(function() {
				ss.onloadcssdefined( cb );
			});
		}
	};
	ss.onloadcssdefined(function() {
		ss.media = "all";
		if(callback){
			callback();
		}
	});
	return ss;
}
window.loadCSS = loadCSS;
